static List*
get_columnnames( List* candidates )

{
    int proc;
    int ret;
    StringInfoData  query;  /* string for Query */
    StringInfoData  cols;   /* string for Columns */
    Oid             advise_oid;
    ListCell        *cell;
    int b=0;

    IndexCandidate* idxcd;

    elog( DEBUG3, "IND ADV: get_column_names: ENTER" );


    initStringInfo( &query );
    initStringInfo( &cols );

    foreach( cell, candidates ) /* foreach cell in candidates */
    {

        idxcd = (IndexCandidate*)lfirst( cell );

        if( !idxcd->idxused )
            continue;

        if (idxcd!=NULL)
        {

            int i;

            /* pfree() the memory allocated for the previous candidate. FIXME: Avoid
            * meddling with the internals of a StringInfo, and try to use an API.
            */
            if( cols.len > 0 )
            {
                pfree( cols.data );
                cols.data = NULL;
            } /*IF col.len>0*/
            appendStringInfo( &query, "select a.attname from pg_class c,pg_attribute a where c.oid=%d AND a.attrelid = c.oid AND (", idxcd->reloid);

            for (i = 0; i < idxcd->ncols; ++i)
            {
                appendStringInfo( &cols, "%s a.attnum=%d", (i>0 ? " OR" : ""), idxcd->varattno[i]);

            }/* foreach col in varattno*/

            appendStringInfo( &cols, "%s", ")");

            /* FIXME: Mention the column names explicitly after the table name. */
            appendStringInfo( &query, "%s;", cols.data);

            if( query.len > 0 ) /* if we generated any SQL */
            {

                if( SPI_connect() == SPI_OK_CONNECT )
                {
                        ret=SPI_exec(query.data, 0);
                        proc=SPI_processed;
                    elog(INFO,"proc:%d", query.len);
                    if( ret>0 )
                    {
                        b=1;

                        if( SPI_tuptable != NULL)
                         {
                            SPITupleTable *tuptable = SPI_tuptable;
                            TupleDesc tupdesc = tuptable->tupdesc;
                            char buf[8192];
                            int i,j;

                            for(j=0;j<proc;j++)
                            {

                                HeapTuple tuple=tuptable->vals[j];  
                                if (tuple!=NULL)
                                {

                                    for (i=1,buf[0]=0;i<=tupdesc->natts;i++)
                                    {
                                        /* cada columna de cada fila*/
                                        char *data;
                                        data=SPI_getvalue(tuple,tupdesc,i);
                                        idxcd->varattnombres[j]=data;
                                        snprintf(buf + strlen (buf), sizeof(buf) - strlen(buf), " %s%s", SPI_getvalue(tuple, tupdesc, i),(i == tupdesc->natts) ? " " : " |");
                                    } /* (i=0,buf[0]=0;i<tupdesc->natts;i++)*/
                                    elog (INFO, "EXECQ: %s", buf);
                                } /* if (tuple!=null)*/
                                else
                                    elog( WARNING, "IND ADV: tuple is null." );
                        }   /* (j=0;j<proc;j++)*/
                    }   /*if( SPI_tuptable != NULL)*/
                    else
                        elog( WARNING, "IND ADV: SPI_tuptable is null." );
                }
                else    
                      elog( WARNING, "IND ADV: SPI_execute failed while select." );
                if( SPI_finish() != SPI_OK_FINISH )
                elog( WARNING, "IND ADV: SPI_finish failed while select." );

            } /*if( SPI_connect() == SPI_OK_CONNECT )*/         

            else
            elog( WARNING, "IND ADV: SPI_connect failed while select." );

            } /*if( query.len > 0 )*/
        } /*if (idxcd!=null)*/
        else
            elog( INFO, "idxcd IS NULL" );
    }   /* foreach cell in candidates */

    /* TODO: Propose to -hackers to introduce API to free a StringInfoData . */
    if ( query.len > 0 )
        pfree( query.data );

    elog( DEBUG3, "IND ADV: select: EXIT" );
    return candidates;
}